( cd usr/lib64 ; rm -rf libedit.so )
( cd usr/lib64 ; ln -sf libedit.so.0.0.36 libedit.so )
( cd usr/lib64 ; rm -rf libedit.so.0 )
( cd usr/lib64 ; ln -sf libedit.so.0.0.36 libedit.so.0 )
( cd usr/man/man3 ; rm -rf el_tok_end.3.gz )
( cd usr/man/man3 ; ln -sf editline.3.gz el_tok_end.3.gz )
( cd usr/man/man3 ; rm -rf el_set.3.gz )
( cd usr/man/man3 ; ln -sf editline.3.gz el_set.3.gz )
( cd usr/man/man3 ; rm -rf el_push.3.gz )
( cd usr/man/man3 ; ln -sf editline.3.gz el_push.3.gz )
( cd usr/man/man3 ; rm -rf el_resize.3.gz )
( cd usr/man/man3 ; ln -sf editline.3.gz el_resize.3.gz )
( cd usr/man/man3 ; rm -rf el_parse.3.gz )
( cd usr/man/man3 ; ln -sf editline.3.gz el_parse.3.gz )
( cd usr/man/man3 ; rm -rf el_line.3.gz )
( cd usr/man/man3 ; ln -sf editline.3.gz el_line.3.gz )
( cd usr/man/man3 ; rm -rf el_init.3.gz )
( cd usr/man/man3 ; ln -sf editline.3.gz el_init.3.gz )
( cd usr/man/man3 ; rm -rf el_insertstr.3.gz )
( cd usr/man/man3 ; ln -sf editline.3.gz el_insertstr.3.gz )
( cd usr/man/man3 ; rm -rf el_getc.3.gz )
( cd usr/man/man3 ; ln -sf editline.3.gz el_getc.3.gz )
( cd usr/man/man3 ; rm -rf el_tok_str.3.gz )
( cd usr/man/man3 ; ln -sf editline.3.gz el_tok_str.3.gz )
( cd usr/man/man3 ; rm -rf el_history.3.gz )
( cd usr/man/man3 ; ln -sf editline.3.gz el_history.3.gz )
( cd usr/man/man3 ; rm -rf el_reset.3.gz )
( cd usr/man/man3 ; ln -sf editline.3.gz el_reset.3.gz )
( cd usr/man/man3 ; rm -rf el_source.3.gz )
( cd usr/man/man3 ; ln -sf editline.3.gz el_source.3.gz )
( cd usr/man/man3 ; rm -rf el_get.3.gz )
( cd usr/man/man3 ; ln -sf editline.3.gz el_get.3.gz )
( cd usr/man/man3 ; rm -rf el_end.3.gz )
( cd usr/man/man3 ; ln -sf editline.3.gz el_end.3.gz )
( cd usr/man/man3 ; rm -rf el_tok_line.3.gz )
( cd usr/man/man3 ; ln -sf editline.3.gz el_tok_line.3.gz )
( cd usr/man/man3 ; rm -rf el_tok_init.3.gz )
( cd usr/man/man3 ; ln -sf editline.3.gz el_tok_init.3.gz )
( cd usr/man/man3 ; rm -rf el_history_end.3.gz )
( cd usr/man/man3 ; ln -sf editline.3.gz el_history_end.3.gz )
( cd usr/man/man3 ; rm -rf el_deletestr.3.gz )
( cd usr/man/man3 ; ln -sf editline.3.gz el_deletestr.3.gz )
( cd usr/man/man3 ; rm -rf el_history_init.3.gz )
( cd usr/man/man3 ; ln -sf editline.3.gz el_history_init.3.gz )
( cd usr/man/man3 ; rm -rf el_tok_reset.3.gz )
( cd usr/man/man3 ; ln -sf editline.3.gz el_tok_reset.3.gz )
( cd usr/man/man3 ; rm -rf el_gets.3.gz )
( cd usr/man/man3 ; ln -sf editline.3.gz el_gets.3.gz )
